@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE Safe #-}
 
 module System.Log.FastLogger.LogStr (
     Builder
@@ -13,11 +14,13 @@ module System.Log.FastLogger.LogStr (
 
 import Data.ByteString.Builder (Builder)
 import qualified Data.ByteString.Builder as B
+import Data.ByteString (ByteString)
 import qualified Data.ByteString as BS
 import qualified Data.ByteString.Char8 as S8
-import Data.ByteString.Internal (ByteString(..))
 import qualified Data.ByteString.Lazy as BL
+#if __GLASGOW_HASKELL__ < 709
 import Data.Monoid (Monoid, mempty, mappend)
+#endif
 #if MIN_VERSION_base(4,5,0)
 import Data.Monoid ((<>))
 #endif
@@ -38,7 +41,11 @@ toBuilder :: ByteString -> Builder
 toBuilder = B.byteString
 
 fromBuilder :: Builder -> ByteString
+#if MIN_VERSION_bytestring(0,10,0)
 fromBuilder = BL.toStrict . B.toLazyByteString
+#else
+fromBuilder = BS.concat . BL.toChunks . B.toLazyByteString
+#endif
 
 ----------------------------------------------------------------
 
